tks - Tkinter Stuff
===================

This is 'tks' a collection of Tkinter widgets

For documentation see https://tks.readthedocs.io/en/latest/index.html

.. image:: https://github.com/sffjunkie/tks/blob/master/src/doc/.static/date_dialog.png

.. image:: https://github.com/sffjunkie/tks/blob/master/src/doc/.static/time_24_hour.png

.. image:: https://github.com/sffjunkie/tks/blob/master/src/doc/.static/color_dialog.png

.. image:: https://github.com/sffjunkie/tks/blob/master/src/doc/.static/color_palette.png

.. image:: https://github.com/sffjunkie/tks/blob/master/src/doc/.static/password_dialog.png
